@@ -95,20 +95,13 @@ fn get(m: &ArgMatches) -> Result<()> {
 
     let dry_run = m.is_present("dry_run");
     let count = authorized_keys.write_keys(keys, dry_run)?;
-    println!(
-        "{} {} new keys",
-        if dry_run { "Found" } else { "Added" },
-        count
-    );
+    println!("{} {} new keys", if dry_run { "Found" } else { "Added" }, count);
 
     Ok(())
 }
 
 /// Adds a new schedule for the Systemd service to run
 fn set(m: &ArgMatches) -> Result<()> {
-    #[cfg(not(target_os = "linux"))]
-    panic!("Platform not supported");
-
     // Get variables
     let user: String = if m.is_present("user") {
         value_t!(m, "user", String)?
@@ -156,7 +149,10 @@ fn set(m: &ArgMatches) -> Result<()> {
         let database = Database::open()?;
         for url in urls {
             if database.add_schedule(&user, &cron.to_string(), &url)? {
-                println!("Successfully added import schedule with url: {}", url);
+                println!(
+                    "Successfully added import schedule with url: {}",
+                    url
+                );
             } else {
                 return Err(anyhow!("Job already exists"));
             }
@@ -174,9 +170,6 @@ fn set(m: &ArgMatches) -> Result<()> {
 
 /// Prints currently set jobs
 fn jobs(m: &ArgMatches) -> Result<()> {
-    #[cfg(not(target_os = "linux"))]
-    panic!("Platform not supported");
-
     if !m.is_present("skip_check") {
         service::check()?
     };
@@ -207,9 +200,6 @@ fn jobs(m: &ArgMatches) -> Result<()> {
 
 /// Removes a schedule by id
 fn remove(m: &ArgMatches) -> Result<()> {
-    #[cfg(not(target_os = "linux"))]
-    panic!("Platform not supported");
-
     util::run_as_root(None)?;
 
     if !m.is_present("skip_check") {
@@ -234,9 +224,6 @@ fn remove(m: &ArgMatches) -> Result<()> {
 
 /// To be run by Systemd, runs until stopped
 fn daemon(m: &ArgMatches) -> Result<()> {
-    #[cfg(not(target_os = "linux"))]
-    panic!("Platform not supported");
-
     let install = m.is_present("install");
     let enable = m.is_present("enable");
 
